@@ -1675,8 +1675,18 @@ if (run_more) {
 ## plot.vsel() ------------------------------------------------------------
 
 cre_args_plot_vsel <- function(args_obj) {
+  tstsetups <- grep("\\.brnll\\..*\\.trad", names(args_obj), value = TRUE)
+  tstsetups <- union(
+    tstsetups,
+    grep("\\.default_search_trms|\\.alltrms", names(args_obj), value = TRUE,
+         invert = TRUE)
+  )
+  tstsetups <- union(
+    tstsetups,
+    head(grep("\\.spclformul", names(args_obj), value = TRUE), 1)
+  )
   lapply(
-    setNames(nm = grep("\\.brnll\\.", names(args_obj), value = TRUE)),
+    setNames(nm = tstsetups),
     function(tstsetup_vsel) {
       nterms_max_plot <- nterms_max_smmry[c("default_nterms_max_smmry",
                                             "halfway")]
